@@ -5,7 +5,7 @@ import kubernetes
 from ocp_resources.constants import TIMEOUT_4MINUTES
 from ocp_resources.node import Node
 from ocp_resources.resource import NamespacedResource
-from ocp_resources.utils import TimeoutWatch
+from timeout_sampler import TimeoutWatch
 
 
 class ExecOnPodError(Exception):
